@@ -35,7 +35,13 @@ import warnings
 
 from django.conf import settings
 
-class SlowerDevServerMiddleware(object):
+try:
+    from django.utils.deprecation import MiddlewareMixin
+except ImportError:
+    MiddlewareMixin = object  # fallback for Django < 1.10
+
+
+class SlowerDevServerMiddleware(MiddlewareMixin):
     def __init__(self):
         warnings.warn("Slower developer server used!")
         
@@ -43,4 +49,4 @@ class SlowerDevServerMiddleware(object):
         if response.status_code == 200: 
             print("SlowerDevServerMiddleware: Wait for %sSec..." % settings.SLOWER_DEV_SERVER_SLEEP)
             time.sleep(settings.SLOWER_DEV_SERVER_SLEEP)
-        return response
\ No newline at end of file
+        return response
